==> nucypher-0.1.0a22-py3-none-any.whl: nucypher/characters/banners.py <==
import nucypher


NU_BANNER = r'''
        
███╗   ██╗██╗   ██╗
████╗  ██║██║   ██║
██╔██╗ ██║██║   ██║
██║╚██╗██║██║   ██║
██║ ╚████║╚██████╔╝
╚═╝  ╚═══╝ ╚═════╝ 
        
'''

NUCYPHER_BANNER = """

_____   __      _________               ______              
___  | / /___  ___  ____/____  ____________  /______________
__   |/ /_  / / /  /    __  / / /__  __ \_  __ \  _ \_  ___/
_  /|  / / /_/ // /___  _  /_/ /__  /_/ /  / / /  __/  /    
/_/ |_/  \__,_/ \____/  _\__, / _  .___//_/ /_/\___//_/     
                        /____/  /_/                         

version {}
""".format(nucypher.__version__)


ALICE_BANNER = r"""

    / \  | (_) ___ ___
   / _ \ | | |/ __/ _ \
  / ___ \| | | (_|  __/
 /_/   \_|_|_|\___\___|

 the Authority.
"""


BOB_BANNER = r"""

oooooooooo              oooo       
 888    888   ooooooo    888ooooo  
 888oooo88  888     888  888    888
 888    888 888     888  888    888
o888ooo888    88ooo88   o888ooo88  

the BUIDLer.
"""


ENRICO_BANNER = r"""
 ___                
 )_  _   _ o  _  _  
(__ ) ) )  ( (_ (_) 

the Encryptor.
{}
"""


MOE_BANNER = r"""
 _______               
|   |   |.-----..-----.
|       ||  _  ||  -__|
|__|_|__||_____||_____|

the Monitor.
"""


URSULA_BANNER = r'''


 ,ggg,         gg                                                     
dP""Y8a        88                                   ,dPYb,            
Yb, `88        88                                   IP'`Yb            
 `"  88        88                                   I8  8I            
     88        88                                   I8  8'            
     88        88   ,gggggg,    ,g,     gg      gg  I8 dP    ,gggg,gg 
     88        88   dP""""8I   ,8'8,    I8      8I  I8dP    dP"  "Y8I 
     88        88  ,8'    8I  ,8'  Yb   I8,    ,8I  I8P    i8'    ,8I 
     Y8b,____,d88,,dP     Y8,,8'_   8) ,d8b,  ,d8b,,d8b,_ ,d8,   ,d8b,
      "Y888888P"Y88P      `Y8P' "YY8P8P8P'"Y88P"`Y88P'"Y88P"Y8888P"`Y8


the Untrusted Re-Encryption Proxy.
{}
'''

FELIX_BANNER = r"""

'||''''|        '||`            
 ||  .           ||   ''        
 ||''|   .|''|,  ||   ||  \\  //
 ||      ||..||  ||   ||    ><  
.||.     `|...  .||. .||. //  \\


the Unlicensed Faucet Plumber
{}
"""

==> nucypher-2.1.0b6-py3-none-any.whl: nucypher/characters/banners.py <==
import nucypher


NU_BANNER = r'''
        
███╗   ██╗██╗   ██╗
████╗  ██║██║   ██║
██╔██╗ ██║██║   ██║
██║╚██╗██║██║   ██║
██║ ╚████║╚██████╔╝
╚═╝  ╚═══╝ ╚═════╝ 
        
'''

NUCYPHER_BANNER = r"""

_____   __      _________               ______              
___  | / /___  ___  ____/____  ____________  /______________
__   |/ /_  / / /  /    __  / / /__  __ \_  __ \  _ \_  ___/
_  /|  / / /_/ // /___  _  /_/ /__  /_/ /  / / /  __/  /    
/_/ |_/  \__,_/ \____/  _\__, / _  .___//_/ /_/\___//_/     
                        /____/  /_/                         

version {}
""".format(nucypher.__version__)


ALICE_BANNER = r"""

    / \  | (_) ___ ___
   / _ \ | | |/ __/ _ \
  / ___ \| | | (_|  __/
 /_/   \_|_|_|\___\___|

 the Authority.
"""


BOB_BANNER = r"""

oooooooooo              oooo       
 888    888   ooooooo    888ooooo  
 888oooo88  888     888  888    888
 888    888 888     888  888    888
o888ooo888    88ooo88   o888ooo88  

the BUIDLer.
"""


ENRICO_BANNER = r"""
 ___                
 )_  _   _ o  _  _  
(__ ) ) )  ( (_ (_) 

the Encryptor.
{}
"""


MOE_BANNER = r"""
 _______               
|   |   |.-----..-----.
|       ||  _  ||  -__|
|__|_|__||_____||_____|

the Monitor.
"""


URSULA_BANNER = r'''


 ,ggg,         gg                                                     
dP""Y8a        88                                   ,dPYb,            
Yb, `88        88                                   IP'`Yb            
 `"  88        88                                   I8  8I            
     88        88                                   I8  8'            
     88        88   ,gggggg,    ,g,     gg      gg  I8 dP    ,gggg,gg 
     88        88   dP""""8I   ,8'8,    I8      8I  I8dP    dP"  "Y8I 
     88        88  ,8'    8I  ,8'  Yb   I8,    ,8I  I8P    i8'    ,8I 
     Y8b,____,d88,,dP     Y8,,8'_   8) ,d8b,  ,d8b,,d8b,_ ,d8,   ,d8b,
      "Y888888P"Y88P      `Y8P' "YY8P8P8P'"Y88P"`Y88P'"Y88P"Y8888P"`Y8


the Untrusted Re-Encryption Proxy.
{}
'''

FELIX_BANNER = r"""

'||''''|        '||`            
 ||  .           ||   ''        
 ||''|   .|''|,  ||   ||  \\  //
 ||      ||..||  ||   ||    ><  
.||.     `|...  .||. .||. //  \\


the Unlicensed Faucet Plumber
{}
"""

STAKEHOLDER_BANNER = r"""
 ____    __            __                      
/\  _`\ /\ \__        /\ \                     
\ \,\L\_\ \ ,_\    __ \ \ \/'\      __   _ __  
 \/_\__ \\ \ \/  /'__`\\ \ , <    /'__`\/\`'__\
   /\ \L\ \ \ \_/\ \L\.\\ \ \\`\ /\  __/\ \ \/ 
   \ `\____\ \__\ \__/.\_\ \_\ \_\ \____\\ \_\ 
    \/_____/\/__/\/__/\/_/\/_/\/_/\/____/ \/_/ 
   
The Holder of Stakes.                                      
"""


WORKLOCK_BANNER = r"""
 _    _               _     _                   _    
| |  | |             | |   | |                 | |   
| |  | |  ___   _ __ | | __| |      ___    ___ | | __
| |/\| | / _ \ | '__|| |/ /| |     / _ \  / __|| |/ /
\  /\  /| (_) || |   |   < | |____| (_) || (__ |   < 
 \/  \/  \___/ |_|   |_|\_\\_____/ \___/  \___||_|\_\

══ {} ══                                                   
"""
